pub struct FPConfig {
pub remote_url: Url,
pub toggles_url: Option<Url>,
pub events_url: Option<Url>,
pub server_sdk_key: String,
pub refresh_interval: Duration,
pub http_client: Option<Client>,
pub start_wait: Option<Duration>,
pub realtime_url: Option<Url>,
pub realtime_path: Option<String>,
}
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.